@@ -10,6 +10,8 @@
 
 #include "gexiv2-metadata.h"
 #include "gexiv2-metadata-private.h"
+#include "gexiv2-util-private.h"
+
 #include <string>
 #include <cmath>
 #include <stdexcept>
@@ -17,8 +19,6 @@
 #include <glib-object.h>
 #include <exiv2/exiv2.hpp>
 
-#include <limits>
-
 G_BEGIN_DECLS
 
 static double convert_rational(const Exiv2::Rational& r) {
@@ -90,9 +90,11 @@ gboolean gexiv2_metadata_try_get_gps_longitude (GExiv2Metadata *self, gdouble *l
 
         return TRUE;
     } catch (Exiv2::Error &e) {
-        g_set_error_literal(error, g_quark_from_string("GExiv2"), static_cast<int>(e.code()), e.what());
+        error << e;
     } catch (std::invalid_argument &e) {
         g_set_error_literal(error, g_quark_from_string("GExiv2"), 0, e.what());
+    } catch (std::exception& e) {
+        error << e;
     }
 
     return FALSE;
@@ -141,9 +143,11 @@ gboolean gexiv2_metadata_try_get_gps_latitude (GExiv2Metadata *self, gdouble *la
 
         return TRUE;
     } catch (Exiv2::Error &e) {
-        g_set_error_literal(error, g_quark_from_string("GExiv2"), static_cast<int>(e.code()), e.what());
+        error << e;
     } catch (std::invalid_argument &e) {
         g_set_error_literal(error, g_quark_from_string("GExiv2"), 0, e.what());
+    } catch (std::exception& e) {
+        error << e;
     }
 
     return FALSE;
@@ -181,9 +185,11 @@ gboolean gexiv2_metadata_try_get_gps_altitude (GExiv2Metadata *self, gdouble *al
 
         return TRUE;
     } catch (Exiv2::Error &e) {
-        g_set_error_literal(error, g_quark_from_string("GExiv2"), static_cast<int>(e.code()), e.what());
+        error << e;
     } catch (std::invalid_argument &e) {
         g_set_error_literal(error, g_quark_from_string("GExiv2"), 0, e.what());
+    } catch (std::exception& e) {
+        error << e;
     }
 
     return FALSE;
@@ -300,7 +306,9 @@ gboolean gexiv2_metadata_try_set_gps_info (GExiv2Metadata *self, gdouble longitu
 
         return gexiv2_metadata_try_update_gps_info (self, longitude, latitude, altitude, error);
     } catch (Exiv2::Error &e) {
-        g_set_error_literal(error, g_quark_from_string("GExiv2"), static_cast<int>(e.code()), e.what());
+        error << e;
+    } catch (std::exception& e) {
+        error << e;
     }
 
     return FALSE;
@@ -393,7 +401,9 @@ gboolean gexiv2_metadata_try_update_gps_info (GExiv2Metadata *self, gdouble long
         
         return TRUE;
     } catch (Exiv2::Error &e) {
-        g_set_error_literal(error, g_quark_from_string("GExiv2"), static_cast<int>(e.code()), e.what());
+        error << e;
+    } catch (std::exception& e) {
+        error << e;
     }
 
     return FALSE;
@@ -434,7 +444,9 @@ void gexiv2_metadata_try_delete_gps_info (GExiv2Metadata *self, GError **error)
                 ++exif_it;
         }
     } catch (Exiv2::Error& e) {
-        g_set_error_literal(error, g_quark_from_string("GExiv2"), static_cast<int>(e.code()), e.what());
+        error << e;
+    } catch (std::exception& e) {
+        error << e;
     }
     
     /* FIXME: two blocks shall ensure to erase in xmp data, if erasing in exif
@@ -453,8 +465,9 @@ void gexiv2_metadata_try_delete_gps_info (GExiv2Metadata *self, GError **error)
         }
         
     } catch (Exiv2::Error& e) {
-        if (error && *error == nullptr)
-            g_set_error_literal(error, g_quark_from_string("GExiv2"), static_cast<int>(e.code()), e.what());
+        error << e;
+    } catch (std::exception& e) {
+        error << e;
     }
 }
 
