@@ -343,25 +343,30 @@ static void gexiv2_metadata_class_init (GExiv2MetadataClass *klass) {
     gobject_class->finalize = gexiv2_metadata_finalize;
 }
 
+static void gexiv2_metadata_free_impl(GExiv2MetadataPrivate* priv) {
+    delete priv->preview_manager;
 
-static void gexiv2_metadata_finalize (GObject *object) {
-    GExiv2Metadata *self = GEXIV2_METADATA (object);
-    
-    g_free (self->priv->comment);
-    g_free (self->priv->mime_type);
-    delete self->priv->preview_manager;
-    
-    if (self->priv->preview_properties != NULL) {
+    if (priv->preview_properties != NULL) {
         int ctr = 0;
-        while (self->priv->preview_properties[ctr] != NULL)
-            gexiv2_preview_properties_free(self->priv->preview_properties[ctr++]);
-        
-        g_free (self->priv->preview_properties);
+        while (priv->preview_properties[ctr] != NULL)
+            gexiv2_preview_properties_free(priv->preview_properties[ctr++]);
+
+        g_free(priv->preview_properties);
     }
-    
-    if (self->priv->image.get() != NULL)
-        self->priv->image.reset();
-    
+
+    if (priv->image.get() != NULL)
+        priv->image.reset();
+}
+
+static void gexiv2_metadata_finalize(GObject* object) {
+    GExiv2Metadata* self = GEXIV2_METADATA(object);
+    auto* priv = (GExiv2MetadataPrivate*) gexiv2_metadata_get_instance_private(self);
+
+    g_free(priv->comment);
+    g_free(priv->mime_type);
+
+    gexiv2_metadata_free_impl(priv);
+
     G_OBJECT_CLASS (gexiv2_metadata_parent_class)->finalize (object);
 }
 
@@ -394,6 +399,7 @@ static void gexiv2_metadata_init_internal(GExiv2Metadata* self, GError** error)
     try {
 
         gexiv2_metadata_set_comment_internal(self, priv->image->comment().c_str());
+        g_clear_pointer(&priv->mime_type, g_free);
         priv->mime_type = g_strdup(priv->image->mimeType().c_str());
 
         priv->pixel_width = priv->image->pixelWidth();
@@ -485,7 +491,7 @@ static std::string convert_path(const char* path, GError** error) {
 
         g_free(msg);
 
-        return FALSE;
+        return {};
     }
     file = local_path;
     g_free(local_path);
@@ -501,6 +507,9 @@ static std::string convert_path(const char* path, GError** error) {
 
 gboolean gexiv2_metadata_open_path(GExiv2Metadata* self, const gchar* path, GError** error) {
     g_return_val_if_fail(GEXIV2_IS_METADATA(self), FALSE);
+
+    gexiv2_metadata_free_impl(self->priv);
+
     try {
         GError* inner_error = nullptr;
 
@@ -514,7 +523,6 @@ gboolean gexiv2_metadata_open_path(GExiv2Metadata* self, const gchar* path, GErr
 
         return gexiv2_metadata_open_internal (self, error);
     } catch (Exiv2::Error &e) {
-
         error << e;
     }
 #ifdef EXV_UNICODE_PATH
@@ -531,7 +539,9 @@ gboolean gexiv2_metadata_open_path(GExiv2Metadata* self, const gchar* path, GErr
 
 gboolean gexiv2_metadata_open_buf(GExiv2Metadata* self, const guint8* data, glong n_data, GError** error) {
     g_return_val_if_fail (GEXIV2_IS_METADATA (self), FALSE);
-    
+
+    gexiv2_metadata_free_impl(self->priv);
+
     try {
         self->priv->image = Exiv2::ImageFactory::open (data, n_data);
         
@@ -548,6 +558,8 @@ gboolean gexiv2_metadata_open_buf(GExiv2Metadata* self, const guint8* data, glon
 gboolean gexiv2_metadata_open_stream (GExiv2Metadata *self, ManagedStreamCallbacks* cb, GError **error) {
     g_return_val_if_fail (GEXIV2_IS_METADATA (self), FALSE);
 
+    gexiv2_metadata_free_impl(self->priv);
+
     try {
         StreamIo::ptr_type stream_ptr{new StreamIo (cb)};
 #if EXIV2_TEST_VERSION(0,27,99)
@@ -569,6 +581,8 @@ gboolean gexiv2_metadata_open_stream (GExiv2Metadata *self, ManagedStreamCallbac
 gboolean gexiv2_metadata_from_stream(GExiv2Metadata *self, GInputStream *stream, GError **error) {
     g_return_val_if_fail (GEXIV2_IS_METADATA (self), FALSE);
 
+    gexiv2_metadata_free_impl(self->priv);
+
     try {
         GioIo::ptr_type gio_ptr{new GioIo (stream)};
 #if EXIV2_TEST_VERSION(0,27,99)
@@ -600,7 +614,9 @@ gboolean gexiv2_metadata_from_app1_segment(GExiv2Metadata* self, const guint8* d
     g_return_val_if_fail(GEXIV2_IS_METADATA(self), FALSE);
     g_return_val_if_fail(data != nullptr, FALSE);
     g_return_val_if_fail(n_data > 0, FALSE);
-    
+
+    gexiv2_metadata_free_impl(self->priv);
+
     int offset = 0;
     while (offset < n_data - 1) {
         if ((data[offset] == 0x4D && data[offset + 1] == 0x4D)
